summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRomain Forlot <romain.forlot@iot.bzh>2017-05-09 13:17:16 +0200
committerRomain Forlot <romain.forlot@iot.bzh>2017-05-09 13:17:16 +0200
commit741d3a45300756c98efce668fa3a5ef9e6b95ec9 (patch)
treeb4beae30225fbaaea9a30fdb858b0edf1b90c5e7
parentd8e7184bad0fe77e5cdd95b5cf93b8d8fdecc88a (diff)
Rework dependencies about custom target to be more CMake compliant
CMake dependencies about custom target is to added with add_dependencies() DEPENDS options is more for output file dependencies. Change-Id: I3fb6b17e0de97bbb495471d50562d41f6ab549f0 Signed-off-by: Romain Forlot <romain.forlot@iot.bzh>
-rw-r--r--reference/etc/macros.cmake7
1 files changed, 4 insertions, 3 deletions
diff --git a/reference/etc/macros.cmake b/reference/etc/macros.cmake
index b89094a..210ed91 100644
--- a/reference/etc/macros.cmake
+++ b/reference/etc/macros.cmake
@@ -243,13 +243,14 @@ if(EXTRA_DEPENDENCIES_ORDER)
)
endif()
# Print developer helper message when everything is done
# -------------------------------------------------------
macro(project_closing_msg)
if(CLOSING_MESSAGE AND GLOBAL_TARGET_LIST)
- add_custom_target(${PROJECT_NAME}_done ALL
- DEPENDS ${DEPENDENCIES_TARGET} ${GLOBAL_TARGET_LIST}
+ add_custom_target(${PROJECT_NAME}_build_done ALL
COMMAND ${CMAKE_COMMAND} -E cmake_echo_color --cyan "++ ${CLOSING_MESSAGE}"
)
+ add_dependencies(${PROJECT_NAME}_build_done
+ ${DEPENDENCIES_TARGET} ${GLOBAL_TARGET_LIST})
endif()
endmacro()
@@ -243,13 +243,14 @@ if(EXTRA_DEPENDENCIES_ORDER)
)
endif()
-# Print developer helper message when everything is done
+# Print developer helper message when build is done
# -------------------------------------------------------
macro(project_closing_msg)